# marshmallow-meta

*decorator syntax for marshmallow meta attributes (with inheritance)*

Decorators communicate that the behavior of a class is being modified and are more concise when only a few meta attributes are needed. Making inheritance the default further reduces the boilerplate needed to make minor changes to a subclass.

## Install

```sh
pip install marshmallow-meta
```

```py
from marshmallow_meta import meta
```

## API

### `@meta(*kwargs)`

Build a meta class that inherits attributes from the base schema's meta class.

```py
@meta(unknown=INCLUDE)
class Test(Schema):
    foo = fields.String()
```

### `@meta(*bases, **kwargs)`

Inherit and extend specific meta classes.

```py
@meta(Test.Meta, many=True)
class CopyCats(Schema):
   bar = fields.String()
```

Or clear the inherited meta class.

```py
@meta(Schema.Meta)
class Fresh(CopyCats):
   buzz = fields.String()
```
